@@ -173,4 +173,11 @@ get_sites.default <- function(...) {
     output <- parse_site(result)
     return(output)
   }
+}
+
+#' @rdname get_sites
+#' @exportS3Method get_sites NULL
+get_sites.NULL <- function(x, ...) {
+  message("Input is NULL, returning NULL")
+  return(NULL)
 }
\ No newline at end of file
