@@ -1,16 +1,12 @@
-#' @title  Slicer
-#' @param x samples object
-#' @param i iteration in samples list
-#' @description Obtain one of the elements within a samples list
-#' @returns `samples` sliced object
-#' @export
+#' @aliases sub-sub,samples-method
+#' @rdname sub-sub
 setMethod(f = "[[",
           signature = signature(x = "samples", i = "numeric"),
           definition = function(x, i) {
             if (length(i) == 1) {
               out <- new("sample", x@samples[[i]])
             } else {
-              out <- purrr::map(i, function(z) {
+              out <- map(i, function(z) {
                 new("sample", x@samples[[z]])
               })
               out <- new("samples", samples = out)
@@ -18,24 +14,8 @@ setMethod(f = "[[",
             return(out)
           })
 
-#' @title  $
-#' @param x sample object
-#' @param name name of the slot
-#' @description Obtain slots of a sample without using at-mark
-#' @returns `value` at selected slot
-#' @export
-setMethod(f = "$",
-          signature = signature(x = "sample"),
-          definition = function(x, name) {
-            slot(x, name)
-          })
-
-#' @title  $ for samples
-#' @param x samples object
-#' @param name name of the slot
-#' @description Obtain slots of a site without using at-mark
-#' @returns `value` at selected slot
-#' @export
+#' @aliases cash,samples-method
+#' @rdname cash
 setMethod(f = "$",
           signature = signature(x = "samples"),
           definition = function(x, name) {
@@ -46,40 +26,37 @@ setMethod(f = "$",
               unlist()
           })
 
+#' @aliases cash,sample-method
+#' @rdname cash
+setMethod(f = "$",
+          signature = signature(x = "sample"),
+          definition = function(x, name) {
+            slot(x, name)
+          })
 
-#' @title Length Method samples
-#' @export
-#' @param x samples object
-#' @returns `int` representing the length of `samples object`
+#' @aliases length,samples-method
+#' @rdname length
 setMethod(f = "length",
           signature = signature(x = "samples"),
           definition = function(x) {
             length(x@samples)
           })
 
-#' @title c Method - Combine datasets objects
-#' @param x datasets object 1
-#' @param y datasets object 2
-#' @returns concatenated `samples` object
-#' @export
+#' @aliases c,samples-method
+#' @rdname c
 setMethod(f = "c",
           signature = signature(x = "samples"),
           definition = function(x, y) {
-            print("im using this function")
             samp <- new("samples",
-                samples = unlist(c(x@samples,
-                                    y@samples), recursive = FALSE))
+                        samples = unlist(c(x@samples,
+                                           y@samples),
+                                         recursive = FALSE))
             return(samp)
           })
 
-#' @title  Insert sample
-#' @param x samples object
-#' @param i iteration in samples list
-#' @param value The value to be used
-#' @description Obtain one of the elements within a samples list
-#' @returns `samples` object with reassigned values
-#' @export
-setMethod(f = "[[<-",
+#' @aliases sub-subset,samples-method
+#' @rdname sub-subset
+setMethod(f = "[[<-", 
           signature = signature(x = "samples"),
           definition = function(x, i, value) {
             samples <- x@samples
@@ -88,11 +65,8 @@ setMethod(f = "[[<-",
             return(out)
           })
 
-#' @title Assign sample field by numeric index
-#' @param x The sample object.
-#' @param i The column indicator.
-#' @param value The value to be used.
-#' @returns `sample` object with reassigned character values
+#' @aliases subset,sample-method
+#' @rdname subset
 setMethod(f = "[<-",
           signature = signature(x = "sample", i = "character"),
           definition = function(x, i, value) {
@@ -100,4 +74,4 @@ setMethod(f = "[<-",
               slot(x, i[idx]) <- value[idx]
             }
             return(x)
-          })
+          })
\ No newline at end of file
